<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="am">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>አስተዳዳሪ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>አዲስ ተጠቃሚ መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>የ ተጠቃሚ መግለጫ መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>ለ አዲስ ተጠቃሚ የ መግቢያ ቃል ያስገቡ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>የ መግቢያ ቃል ማረጋገጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>ለ አዲስ ተጠቃሚ የ ተጠቃሚ ስም ያስገቡ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>የ ተጠቃሚ የ መግቢያ ስም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>ለ አዲስ ተጠቃሚ የ ተጠቃሚ ስም ያስገቡ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>የ ተጠቃሚ ስም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>የ መግቢያ ቃል ለ አዲስ ተጠቃሚ </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>የ ተጠቃሚ የመግቢያ ቃል:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>ለ አዲስ ተጠቃሚ የ መግቢያ ቃል ያስገቡ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>የ መግቢያ ቃል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>የ ተጠቃሚ የ መግቢያ ቃል ማረጋገጫ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>የ ተጠቃሚ መግለጫ ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>ተጠቃሚ ይምረጡ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>ተጠቃሚ ይምረጡ ለ ማጥፋት</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>የሚጠፋው ተጠቃሚ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>የ ተጠቃሚ ቤት ዳይሬክቶሪ ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>የ ተጠቃሚ ቤት ዳይሬክቶሪ ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>ተጠቃሚ ይምረጡ ለ ማሻሻል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>የ ተጠቃሚ የ መግቢያ ቃል መቀየሪያ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>አዲስ የ መግቢያ ቃል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>አዲስ የ መግቢያ ቃል ማረጋገጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>አዲስ የ መግቢያ ቃል ማረጋገጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>ምርጫዎች</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>የ ተጠቃሚ ማሰናጃ መጠገኛ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>የ ተጠቃሚ መግለጫ ማሻሻያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>ተጠቃሚ ይምረጡ ለ መጠገን</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>ተጠቃሚ ለ መቀየር:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>ነባር እንደ ነበር መመለሻ </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel or Firefox) ማሰናጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>የ ቡድን አባሎች</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>በራሱ መግቢያ ማሰናጃ መቀየሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>ራሱ በራሱ መግቢያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>ለ መግባት የ መግቢያ ቃል ያስፈልጋል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>ኮፒ/ማስማሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>በ ዴስክቶፕ መካከል ኮፒ ማድረጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>ዴስክቶፕ ይምረጡ ኮፒ ለ ማድረግ ከ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>ፋይሎች ይምረጡ ኮፒ ለ ማድረግ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>ኮፒ ብቻ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>ዴስክቶፕ ይምረጡ ኮፒ ለ ማድረግ ወደ </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>ኮፒ ወደ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>ኮፒ ማድረጊያ ከ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>ይምረጡ ኮፒ ለ ማድረግ እና ከዛ ልዩነቱን ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>ማስማሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>ይምረጡ ኮፒ ለ ማድረግ/ለማስማማት: ለ ማካፈል</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>ፎልደር ማካፈያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>ይምረጡ ጠቅላላ ቤት ኮፒ ለ ማድረግ/ለ ማስማማት: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>ጠቅላላ ቤት</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>ይምረጡ የ መቃኛ ማሰናጃ ኮፒ ለ ማድረግ/ለ ማስማማት: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox or Iceweasel) ማሰናጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>ይምረጡ ሰነዶች ኮፒ ለ ማድረግ/ለ ማስማማት: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>የ ሰነዶች ፎልደር</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>ምን ኮፒ/ማስማሚያ ይደረግ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>ሂደት</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>የ ለውጦች ሁኔታ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>ሁኔታው</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>የ ለውጦች ሁኔታ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>ቡድን መጨመሪያ/ማሴስወገጃ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>ቡድም መጨመሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>የ ቡድን ስም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>የ ቡድን ስም</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>ቡድን ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>የሚጠፋው ቡድን</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>የ ቡድን አባሎች</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>ማንኛውንም ለውጥ መፈጸሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>መፈጸሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>ማንኛውንም ለውጥ መሰረዣ እና ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>መዝጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>እርዳታ ማሳያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>ስለዚህ መተግበሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>ስለ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <location filename="../mainwindow.cpp" line="691"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>none</source>
        <translation>ምንም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Autologin options</source>
        <translation>በራሱ መግቢያ ምርጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>በራሱ መግቢያ ተሰናክሏል ለ &apos;%1&apos; መግለጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>በራሱ መግቢያ አስችለዋል ለ &apos;%1&apos; መግለጫ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>እርስዎ መወሰን አለብዎት የ &apos;ኮፒ ወደ&apos; መድረሻ: እርስዎ ኮፒ ማድረግ አይችሊም እርስዎ አሁን ወደ ገቡበት ዴስክቶፕ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Synchronizing desktop...</source>
        <translation>ዴስክቶፕ በ ማስማማት ላይ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copying desktop...</source>
        <translation>ዴስክቶፕ ኮፒ በ ማድረግ ላይ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>የ ተጠቃሚ ስም ቢያንስ መያዝ አለበት 2 ባህሪዎች እርዝመት: እባክዎን ይምረጡ ረጅም ስም ከ መቀጠልዎ በፊት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>የ ተጠቃሚ ስም በ አነስተኛ ፊደል መጻፍ አለበት እና በ ውስጡ
የ ተለየ ባህሪ ወይንም ክፍተት መያዝ የለበትም 
እባክዎን ሌላ ስም ይምረጡ ከ መቀጠልዎት በፊት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>የ መግቢያ ቃል ያስገቡት ተመሳሳይ አይደለም እባክዎን እንደገና ይሞክሩ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>የ መግቢያ ቃል ቢያንስ መያዝ አለበት 2 ባህሪዎች እርዝመት: እባክዎን ይምረጡ ረጅም የ መግቢያ ቃል ከ መቀጠልዎ በፊት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>The user was added ok.</source>
        <translation>ተጠቃሚው ተጨምሯል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>ተጠቃሚ መጨመር አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Password successfully changed.</source>
        <translation>የ መግቢያ ቃል ተሳክቶ ተቀይሯል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Failed to change password.</source>
        <translation>የ መግቢያ ቃል መቀየር አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>ይህን ተግባር መተው አይቻልም: እርስዎ በ እርግጥ ይህን ተጠቃሚ ማጥፋት ይፈልጋሉ %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>ይህን ተጠቃሚ አጥፍተውታል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Failed to delete the user.</source>
        <translation>ይህን ተጠቃሚ ማጥፋት አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>የ ቡድን ስም ቢያንስ መያዝ አለበት 2 ባህሪዎች እርዝመት: እባክዎን ይምረጡ ረጅም ስም ከ መቀጠልዎ በፊት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>የ ቡድን ስም በ አነስተኛ ፊደል መጻፍ አለበት እና በ ውስጡ
የ ተለየ ባህሪ ወይንም ክፍተት መያዝ የለበትም 
እባክዎን ሌላ ስም ይምረጡ ከ መቀጠልዎት በፊት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>The system group was added ok.</source>
        <translation>የ ስርአት ቡድን ተጨምሯል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Failed to add the system group.</source>
        <translation>የ ስርአት ቡድን መጨመር አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>ይህን ተግባር መተው አይቻልም: እርስዎ በ እርግጥ ይህን ቡድን ማጥፋት ይፈልጋሉ %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>The group has been deleted.</source>
        <translation>ይህን ቡድን አጥፍተውታል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Failed to delete the group.</source>
        <translation>ይህን ቡድን ማጥፋት አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The changes have been applied.</source>
        <translation>ለውጦቹ ተፈጽመዋል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Failed to apply group changes</source>
        <translation>የ ቡድን ለውጦችን መፈጸም አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Synchronizing desktop...ok</source>
        <translation>ዴስክቶፕ በ ማስማማት...ላይ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="575"/>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Copying desktop...ok</source>
        <translation>ዴስክቶፕ ኮፒ በ ማድረግ ላይ...እሺ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Synchronizing desktop...failed</source>
        <translation>ዴስክቶፕ ማስማማት አልተቻለም.ወድቋል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Copying desktop...failed</source>
        <translation>ዴስክቶፕ ኮፒ ማድረግ...ወድቋል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <location filename="../mainwindow.cpp" line="888"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>browse...</source>
        <translation>መቃኛ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <source>Version: </source>
        <translation>እትም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Simple user configuration for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="803"/>
        <source>Copyright (c) MX Linux</source>
        <translation>የ ቅጂ መብት (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="819"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>Select folder to copy to</source>
        <translation>ፎልደር ይምረጡ ኮፒ ለ ማድረግ ወደ</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>ፍቃድ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;መዝጊያ</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">ይህን ፕሮግራም እንደ root ማስኬድ አለብዎት</translation>
    </message>
</context>
</TS>
